@@ -42,8 +42,9 @@ from gi.repository import Gtk, Gdk, GLib, Gio, GObject, Gst, GstAudio, GstPbutil
 from gettext import gettext as _, ngettext
 from random import randint
 from collections import deque
-from gnomemusic.albumArtCache import AlbumArtCache
+from gnomemusic.albumartcache import AlbumArtCache, DefaultIcon
 from gnomemusic.playlists import Playlists
+import gnomemusic.utils as utils
 playlists = Playlists.get_default()
 
 from hashlib import md5
@@ -110,8 +111,9 @@ class Player(GObject.GObject):
         self.currentTrackUri = None
         self._lastState = Gst.State.PAUSED
         self.cache = AlbumArtCache.get_default()
-        self._noArtworkIcon = self.cache.get_default_icon(ART_SIZE, ART_SIZE)
-        self._loadingIcon = self.cache.get_default_icon(ART_SIZE, ART_SIZE, True)
+        self._no_artwork_icon = DefaultIcon().get(ART_SIZE,
+                                                  ART_SIZE,
+                                                  DefaultIcon.Type.music)
         self._missingPluginMessages = []
 
         Gst.init(None)
@@ -381,6 +383,7 @@ class Player(GObject.GObject):
                 else:
                     self.currentTrack = None
                 self.load(self.get_current_media())
+            self.emit('playback-status-changed')
         else:
             # Stop playback
             self.stop()
@@ -594,15 +597,9 @@ class Player(GObject.GObject):
         self.playBtn.set_sensitive(True)
         self._sync_prev_next()
 
-        artist = _("Unknown Artist")
-        try:
-            assert media.get_artist() is not None
-            artist = media.get_artist()
-        except:
-            pass
-        finally:
-            self.artistLabel.set_label(artist)
-            self._currentArtist = artist
+        artist = utils.get_artist_name(media)
+        self.artistLabel.set_label(artist)
+        self._currentArtist = artist
 
         album = _("Unknown Album")
         try:
@@ -611,7 +608,7 @@ class Player(GObject.GObject):
         except:
             self._currentAlbum = album
 
-        self.coverImg.set_from_pixbuf(self._noArtworkIcon)
+        self.coverImg.set_from_pixbuf(self._no_artwork_icon)
         self.cache.lookup(
             media, ART_SIZE, ART_SIZE, self._on_cache_lookup, None, artist, album)
 
@@ -656,8 +653,8 @@ class Player(GObject.GObject):
         url = self.playlist.get_value(_iter, 5).get_url()
 
         # Skip remote tracks discovery
-        if url.startswith("http://"):
-            status = DiscoveryStatus.SUCCEEDED
+        if url.startswith('http://') or url.startswith('https://'):
+            return False
         elif status == DiscoveryStatus.PENDING:
             self.discover_item(nextSong, self._on_next_item_validated, _iter)
         elif status == DiscoveryStatus.FAILED:
