@@ -87,8 +87,8 @@ class BaseManager:
             # No need to set the tag there
             if (selected_value[BaseModelColumns.ID] != 'search_all' and
                     selected_value[BaseModelColumns.ID] != 'grl-tracker-source'):
-                self.entry.add_tag(self.tag)
                 self.tag.set_label(selected_value[BaseModelColumns.NAME])
+                self.entry.add_tag(self.tag)
             else:
                 self.entry.remove_tag(self.tag)
 
@@ -243,7 +243,7 @@ class DropDown(Gtk.Revealer):
             self.searchFieldsFilter.view.set_sensitive(id == 'grl-tracker-source')
 
 
-class Searchbar(Gtk.Revealer):
+class Searchbar(Gtk.SearchBar):
 
     def __repr__(self):
         return '<Searchbar>'
@@ -263,10 +263,10 @@ class Searchbar(Gtk.Revealer):
         self._search_entry.show()
         self._searchContainer.add(self._search_entry)
 
-        self._dropDownButtonArrow = Gtk.Arrow(arrow_type=Gtk.ArrowType.DOWN, shadow_type=Gtk.ShadowType.NONE)
+        arrow = Gtk.Image.new_from_icon_name('pan-down-symbolic',
+                                             Gtk.IconSize.BUTTON)
         self._dropDownButton = Gtk.ToggleButton()
-        self._dropDownButton.add(self._dropDownButtonArrow)
-        self._dropDownButton.get_style_context().add_class('raised')
+        self._dropDownButton.add(arrow)
         self._dropDownButton.get_style_context().add_class('image-button')
         self._dropDownButton.connect("toggled", self._drop_down_button_toggled)
         self._dropDownButton.show_all()
@@ -275,16 +275,7 @@ class Searchbar(Gtk.Revealer):
         self._search_entry.connect("tag-button-clicked", self._search_entry_tag_button_clicked)
 
         self._searchContainer.show_all()
-        toolbar = Gtk.Toolbar()
-        toolbar.get_style_context().add_class("search-bar")
-        toolbar.show()
-        self.add(toolbar)
-
-        item = Gtk.ToolItem()
-        item.set_expand(True)
-        item.show()
-        toolbar.insert(item, 0)
-        item.add(self._searchContainer)
+        self.add(self._searchContainer)
 
     @log
     def _drop_down_button_toggled(self, *args):
@@ -323,10 +314,11 @@ class Searchbar(Gtk.Revealer):
 
     @log
     def show_bar(self, show, clear=True):
-        self.set_reveal_child(show)
+        self.set_search_mode(show)
         self._search_button.set_active(show)
 
         if show:
+            self._search_entry.realize()
             if clear:
                 self._search_entry.set_text('')
             self._search_entry.grab_focus()
@@ -335,4 +327,4 @@ class Searchbar(Gtk.Revealer):
 
     @log
     def toggle_bar(self):
-        self.show_bar(not self.get_child_revealed())
+        self.show_bar(not self.get_search_mode())
